==> zio-aws-rds_2.12-5.17.112.1-sources.jar: zio/aws/rds/model/DescribeDbInstanceAutomatedBackupsResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeDbInstanceAutomatedBackupsResponse(
    marker: scala.Option[String] = None,
    dbInstanceAutomatedBackups: scala.Option[Iterable[
      zio.aws.rds.model.DBInstanceAutomatedBackup
    ]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse = {
    import DescribeDbInstanceAutomatedBackupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbInstanceAutomatedBackups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbInstanceAutomatedBackups)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse
      .wrap(buildAwsValue())
}
object DescribeDbInstanceAutomatedBackupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse =
      zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse(
        marker.map(value => value),
        dbInstanceAutomatedBackups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: scala.Option[String]
    def dbInstanceAutomatedBackups: scala.Option[List[
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbInstanceAutomatedBackups: ZIO[Any, AwsError, List[
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "dbInstanceAutomatedBackups",
      dbInstanceAutomatedBackups
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
  ) extends zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse.ReadOnly {
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val dbInstanceAutomatedBackups: scala.Option[List[
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ]] = scala
      .Option(impl.dbInstanceAutomatedBackups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.DBInstanceAutomatedBackup.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
  ): zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.178.1-sources.jar: zio/aws/rds/model/DescribeDbInstanceAutomatedBackupsResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeDbInstanceAutomatedBackupsResponse(
    marker: Optional[String] = Optional.Absent,
    dbInstanceAutomatedBackups: Optional[
      Iterable[zio.aws.rds.model.DBInstanceAutomatedBackup]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse = {
    import DescribeDbInstanceAutomatedBackupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbInstanceAutomatedBackups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbInstanceAutomatedBackups)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse
      .wrap(buildAwsValue())
}
object DescribeDbInstanceAutomatedBackupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse =
      zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse(
        marker.map(value => value),
        dbInstanceAutomatedBackups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Optional[String]
    def dbInstanceAutomatedBackups
        : Optional[List[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbInstanceAutomatedBackups: ZIO[Any, AwsError, List[
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "dbInstanceAutomatedBackups",
      dbInstanceAutomatedBackups
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
  ) extends zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val dbInstanceAutomatedBackups
        : Optional[List[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbInstanceAutomatedBackups())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.DBInstanceAutomatedBackup.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbInstanceAutomatedBackupsResponse
  ): zio.aws.rds.model.DescribeDbInstanceAutomatedBackupsResponse.ReadOnly =
    new Wrapper(impl)
}
